import 'package:flutter/material.dart';
import 'package:flutter_svg/svg.dart';
import 'package:intl/intl.dart';
import 'package:syncrow_web/utils/color_manager.dart';
import 'package:syncrow_web/utils/constants/assets.dart';

class AnalyticsDateFilterButton extends StatelessWidget {
  const AnalyticsDateFilterButton({super.key});

  static final _color = ColorsManager.blackColor.withValues(alpha: 0.8);

  @override
  Widget build(BuildContext context) {
    return TextButton.icon(
      style: TextButton.styleFrom(
        foregroundColor: _color,
        shape: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(16),
          side: const BorderSide(
            color: ColorsManager.greyColor,
            width: 1,
          ),
        ),
        backgroundColor: ColorsManager.transparentColor,
        padding: const EdgeInsets.symmetric(
          horizontal: 32,
          vertical: 16,
        ),
      ),
      icon: SvgPicture.asset(
        Assets.blankCalendar,
        height: 20,
        width: 20,
        colorFilter: ColorFilter.mode(_color, BlendMode.srcIn),
      ),
      label: Text(
        _concatenateDate(DateTime(2024, 1), DateTime(2024, 12)),
        style: const TextStyle(
          fontWeight: FontWeight.w700,
        ),
      ),
      onPressed: () {},
    );
  }

  String _formatDate(DateTime date) {
    final formatter = DateFormat('MMM yyyy');
    final formattedDate = formatter.format(date);
    return formattedDate;
  }

  String _concatenateDate(DateTime startDate, DateTime endDate) {
    final formattedStartDate = _formatDate(startDate);
    final formattedEndDate = _formatDate(endDate);
    return '$formattedStartDate - $formattedEndDate';
  }
}
